mod prepare;
use std::fs;

use poem::{endpoint::StaticFilesEndpoint, listener::TcpListener, Route};
use poem_openapi::{param::Query, payload::Html, payload::PlainText, OpenApi, OpenApiService};
use prepare::{prep, BlogPost};

struct Api {
    blogPosts: Vec<BlogPost>,
}

#[OpenApi]
impl Api {
    #[oai(path = "/posts", method = "get")]
    async fn posts(&self) -> Html<String> {
        Html(self.blogPosts.iter().fold(String::new(), |posts, post| {
            posts + "<li>" + &post.name + "</li>"
        }))
    }
}

#[tokio::main]
async fn main() -> Result<(), std::io::Error> {
    // Load files

    let blog = prep("Blog".to_string());

    let api_service = OpenApiService::new(Api { blogPosts: blog }, "Hello World", "1.0")
        .server("http://localhost:3000/api");

    let ui = api_service.swagger_ui();
    let app = Route::new()
        .nest(
            "/",
            StaticFilesEndpoint::new("static").index_file("index.html"),
        )
        .nest("/api", api_service)
        .nest("/swagger", ui);

    poem::Server::new(TcpListener::bind("127.0.0.1:3000"))
        .run(app)
        .await
}
